@@ -6,7 +6,7 @@
 #include "types.h"
 
 enum fw_version {
-    V_UNKNOWN,
+    V_UNKNOWN = 0,
     V12_1,
     V12_2,
     V12_3,
@@ -23,13 +23,21 @@ enum fw_version {
     V13_5,
     V13_6_2,
     V14_1_1,
+    V15_0B1,
+    V15_0,
     NUM_FW_VERSIONS,
 };
 
+#define FW_MIN V_UNKNOWN
+#define FW_MAX V_UNKNOWN
+
+#define OS_VER_COMP    4
+#define IBOOT_VER_COMP 5
+
 struct fw_version_info {
     enum fw_version version;
     const char *string;
-    u32 num[4];
+    u32 num[OS_VER_COMP];
     size_t num_length;
     const char *iboot;
 };
@@ -40,5 +48,6 @@ extern const struct fw_version_info fw_versions[NUM_FW_VERSIONS];
 
 int firmware_init(void);
 int firmware_set_fdt(void *fdt, int node, const char *prop, const struct fw_version_info *ver);
+bool firmware_sfw_in_range(enum fw_version lower_bound, enum fw_version upper_bound);
 
 #endif
