@@ -358,6 +358,15 @@ int proxy_process(ProxyRequest *request, ProxyReply *reply)
                       request->args[3], request->args[4]);
             reply->retval = smp_wait(request->args[0]);
             break;
+        case P_SMP_CALL_EL0:
+            smp_call4(request->args[0], el0_call, request->args[1], request->args[2],
+                      request->args[3], request->args[4]);
+            break;
+        case P_SMP_CALL_EL0_SYNC:
+            smp_call4(request->args[0], el0_call, request->args[1], request->args[2],
+                      request->args[3], request->args[4]);
+            reply->retval = smp_wait(request->args[0]);
+            break;
 
         case P_HEAPBLOCK_ALLOC:
             reply->retval = (u64)heapblock_alloc(request->args[0]);
